#
# spec file for package icmake
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           icmake
Version:        9.02.02
Release:        bp153.1.18
Summary:        A program maintenance (make) utility using a C-like grammar
License:        GPL-3.0
Group:          Development/Tools/Building
Url:            https://fbb-git.github.io/icmake/
Source:         https://github.com/fbb-git/icmake/archive/%{version}.tar.gz
Patch1:         prevent-double-slash.patch
BuildRequires:  bison
BuildRequires:  flex
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Icmake allows the programmer to use a program language (closely
resembling the well-known C-programming language) to define the
actions involved in (complex) program maintenance. For this, icmake
offers various special operators as well as a set of support functions
that have proven to be useful in program maintenance.

%prep
%setup -q
%patch1 -p1

%build
export CFLAGS="%{optflags} -std=gnu99"
echo "/* created during rpmbuild */" >  %{name}/INSTALL.im
echo "#define BINDIR      \"%{_bindir}\"" >>  %{name}/INSTALL.im
echo "#define SKELDIR     \"%{_datadir}/%{name}\"" >>  %{name}/INSTALL.im
echo "#define MANDIR      \"%{_mandir}\"" >>  %{name}/INSTALL.im
echo "#define LIBDIR      \"%{_libdir}/%{name}\"" >>  %{name}/INSTALL.im
echo "#define CONFDIR     \"%{_sysconfdir}/%{name}\"" >>  %{name}/INSTALL.im
echo "#define DOCDIR      \"%{_docdir}/%{name}\"" >>  %{name}/INSTALL.im
echo "#define DOCDOCDIR   \"%{_docdir}/%{name}\"" >>  %{name}/INSTALL.im
pushd %{name}
./icm_prepare   "/"
./icm_bootstrap ""
popd

%install
pushd %{name}
./icm_install all %{buildroot}
popd

%files
%defattr(-,root,root)
%doc %{name}/changelog
%doc %{_docdir}/%{name}/
%{_bindir}/icmake
%{_bindir}/icmbuild
%{_bindir}/icmstart
%{_mandir}/man1/icmake.1%{ext_man}
%{_mandir}/man1/icmbuild.1%{ext_man}
%{_mandir}/man1/icmstart.1%{ext_man}
%{_mandir}/man7/icmconf.7%{ext_man}
%{_mandir}/man7/icmstart.rc.7%{ext_man}
%{_datadir}/icmake
%dir %{_libdir}/icmake
%{_libdir}/icmake/icm-comp
%{_libdir}/icmake/icm-exec
%{_libdir}/icmake/icm-pp
%{_libdir}/icmake/icm-dep
%{_libdir}/icmake/icmun
%{_libdir}/icmake/icmbuild
%dir %{_sysconfdir}/icmake
%config %{_sysconfdir}/icmake/icmstart.rc

%changelog
* Tue Feb  7 2017 dimstar@opensuse.org
- Explicitly package %%{_docdir}/%%{name} to fix build with RPM 4.13.
* Thu Feb  2 2017 josef.moellers@suse.com
- Upgrade to 9.02.02
  * Fixed an annoying typo in [/usr/lib/icmake/]icmbuild.
- Upgrade to 9.02.01
  * Fixed a flaw in [/usr/lib/icmake/]icmbuild: when DEFCOM "library" was
    defined in icmconf, and precompiled headers were requested, then MAIN had
    to be defined as well. This is not required anymore.
- Upgrade to 9.02.00
  * icmbuild now is a small program, providing help or starting the icmbuild
    script in LIBDIR (cf. INSTALL)
  * Man-pages were updated
  * Cosmetic changes to icmake --help's output
  * The name of the optional configuration file YEAR was changed to YEARS
    (as it defines YEARS, not YEAR)
  * `icmconf' was added to /etc/icmake/icmstart.rc
  * As mentioned in icmake's man-page the program `icmun' is mainly used in
    some specific situations. In icmake's daily practice it isn't
    used. Therefore it was moved from the standard binary programs directory
    to icmake's LIB directory (commonly /usr/lib/icmake).
  * The file /etc/icmake/icmake.rc was nowhere used and was removed.
- Upgrade to 9.01.00
  * Man-pages weren't properly updated at 9.00.00. This was fixed in this
    release.
- Upgrade to 9.00.00
  * Added support program icm-dep computing dependencies for USE_ALL classes
    and precompiled headers, called from /usr/bin/icmbuild, or directly using
    icmake's option --icm-dep (-d)
  * Icmake supports several long options in addition to the standard short
    options. See icmake(1) for details.
  * Changed references to IS_* into O_* in icmake(1)'s man-page. The IS_
    entries were already unavailable, but the man-page still referred to
    them. Now fixed.
  * Contents of lines in CLASSES beyond the first word are no longer
    interpreted.
  * Added new option NO_PRECOMP_WARNING to icmconf
  * Option -b was removed from icmake.
  * The built-in function makelist(mask, [younger,older], referencefile) is now
    operational (was mentioned in icmake's man-page, but wasn't implemented
    before).
  * Repaired a bug in substr that could segfault.
  * Man-pages updated. Icmbuild(1) contains a description of the icm-dep
    program.
* Sun Feb 28 2016 mpluskal@suse.com
- Update to 8.01.00
  * See changelog for details
* Tue Jan 12 2016 mpluskal@suse.com
- Do not run updatescanner as it breaks build
* Sun Jan 10 2016 mpluskal@suse.com
- Update to 8.00.05
  * see attached changelog
- Drop no longer necessary adapt-examples-path.patch
- Don't strip installed binaries
- Cleanup spec file with spec-cleaner
* Fri Dec  4 2015 mpluskal@suse.com
- Revert part of previous changes
- Build with correct cflags
* Thu Dec  3 2015 p.drouand@gmail.com
- Update to version 7.23.04
  * Please read the changelog file
- Update project and download Urls
* Sun Jul 28 2013 p.drouand@gmail.com
- Update to version 7.20.00
  * added missing '\n' to the strtok call in icmbuild's 'dependenciesOf'
    function
  * line continuation in CLASSES results in one line being counted in the
    icmbuild script.
  * Added suggestions by Johann 'Myrkraverk' Oskarsson about compiling icmake
    on solaris (in ./contributions/solaris)
* Thu Jan  3 2013 kkaempf@suse.com
- Clarified license with author: GPL-3.0 (bnc#795979)
* Wed Dec 12 2012 kkaempf@suse.com
- Fix doc path for RedHat/CentOS
* Wed Dec 12 2012 kkaempf@suse.com
- Initial version 7.19.00
